---
title: 导入 SDK
sidebar_position: 30
---

# 导入 SDK

由于 uni-app 的 SDK 是在 uni 原生插件的基础上封装了 Typescript 调用层，导入 SDK 时，必须先引入 uni 原生插件。

## 步骤 1：导入 uni 原生插件

> uni 原生插件均已上架 uni-app 插件市场。
>
>- 即时通讯 uni 原生插件 [RCUniIMV2](https://ext.dcloud.net.cn/plugin?id=9227)
>
>- 实时音视频 uni 原生插件 [RCUniRtc](https://ext.dcloud.net.cn/plugin?id=7418)

请使用 [HBuilder X](https://www.dcloud.io/hbuilderx.html) 将即时通讯 `RCUniIMV2` 插件和实时音视频 `RCUniRtc` 插件导入应用工程。

1. 前往 uni-app 插件市场，购买（0 元）或 下载融云 uni-app 原生插件 [RCUniIMV2](https://ext.dcloud.net.cn/plugin?id=9227) 和 [RCUniRtc](https://ext.dcloud.net.cn/plugin?id=7418)。

2. 使用 HBuilder X 导入原生插件，并完成相应配置。请根据项目打包方式，选择合适的步骤。

    - 云打包适用：

        1. 在插件市场操作`购买（0 元）for 云打包`后，然后在 HBuilder X 中，打开项目的 `manifest.json` 文件。
        2. 点击 **App原生插件配置** -> **选择云端插件** -> 选中 **RCUniIM/RCUniRtc**。

    - 本地打包适用：

        1. 使用 HBuilder X 在项目根目录下创建 `nativeplugins` 文件夹。
        2. 将下载的插件解压之后放入 `nativeplugins` 文件夹中。
        3. 在 HBuilder X 中，打开项目的 `manifest.json` 文件。
        4. 点击 **App原生插件配置** -> **选择本地插件** -> 选中 **RCUniIM/RCUniRtc**。

            请参照以下 `nativeplugins` 文件目录结构：

            ```
            nativeplugins
            └── RongCloud-IM
                ├── android
                │   ├── RCUniIM.aar
                ├── ios
                │   ├── RCUniIM.xcframework
                │   ├── RongChatRoom.xcframework
                │   └── RongIMLibCore.xcframework
                └── package.json
            └── RongCloud-RTC
                ├── android
                │   ├── RCUniRtc-release.aar
                │   ├── libs
                │       ├── RongRTCWrapper.jar
                ├── ios
                │   ├── RCUniRtc.xcframework
                │   └── RongIMLibCore.xcframework
                │   └── RongRTCLib.xcframework
                │   └── RongRTCLibWrapper.xcframework
                └── package.json
            ```

            **目录说明**：

            * `android` 目录：包含融云  uni-app Android 原生插件
            * `ios` 目录：包含融云  uni-app iOS 原生插件
            * `package.json`：插件的依赖


## 步骤 2：安装 Typescript 依赖项

原生插件配置完成后，还需要安装两个 Typescript 层的依赖项。

> uni Typescript 插件均已上架 uni-app 插件市场。
>
>- 即时通讯 Typescript 插件 [RongCloud-IMWrapper-V2](https://ext.dcloud.net.cn/plugin?id=9225)
>
>- 实时音视频 Typescript 插件 [RongCloud-RTCWrapper](https://ext.dcloud.net.cn/plugin?id=7419)

## 步骤 3：在代码中导入 SDK

```js
// IM
import RCIMIWEngine from "@/uni_modules/RongCloud-IMWrapper-V2/js_sdk/RCIMEngine";
// RTC
import RCRTCEngine from '@/uni_modules/RongCloud-RTCWrapper/lib/RCRTCEngine';
```

版本依赖说明

| 依赖SDK  | 版本 |
|:---|:---|
|RTCLib|5.1.17|


